==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/algorith/nmdeze.f <==
      SUBROUTINE NMDEZE (LISCHA,INSTAN,PHASME)

C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGORITH  DATE 06/12/2000   AUTEUR VABHHTS J.PELLET 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================

      IMPLICIT NONE
      CHARACTER*19   LISCHA, PHASME
      REAL*8         INSTAN
C ----------------------------------------------------------------------
C     EXTRACTION DU CHAMP DE CHANGEMENTS DE PHASES METALLURGIQUES
C
C IN        LISCHA  : SD L_CHARGES
C IN        INSTAN  : INSTANT DE L'EXTRACTION
C IN/JXOUT  PHASME  : CHAM_ELEM DE CHANGEMENTS DE PHASES METALLURGIQUES
C ----------------------------------------------------------------------

C --- DEBUT DECLARATIONS NORMALISEES JEVEUX ----------------------------
C
      CHARACTER*32       JEXNUM , JEXNOM , JEXR8 , JEXATR
      INTEGER            ZI
      COMMON  / IVARJE / ZI(1)
      REAL*8             ZR
      COMMON  / RVARJE / ZR(1)
      COMPLEX*16         ZC
      COMMON  / CVARJE / ZC(1)
      LOGICAL            ZL
      COMMON  / LVARJE / ZL(1)
      CHARACTER*8        ZK8
      CHARACTER*16                ZK16
      CHARACTER*24                          ZK24
      CHARACTER*32                                    ZK32
      CHARACTER*80                                              ZK80
      COMMON  / KVARJE / ZK8(1) , ZK16(1) , ZK24(1) , ZK32(1) , ZK80(1)
C
C --- FIN DECLARATIONS NORMALISEES JEVEUX ------------------------------
C
      INTEGER            NCHAR,IRET,NUMCHA,JCHAR,JINF, JTEMP, NBCHAM
      CHARACTER*8        TEMPE,K8BID
      CHARACTER*16       TYSD
      CHARACTER*24       CHARGE, INFCHA, NOM24, LIGRMO



      CALL JEMARQ()
      CALL DETRSD('CHAMP_GD',PHASME)

      CHARGE =  LISCHA // '.LCHA'
      INFCHA =  LISCHA // '.INFC'


C    EXTRACTION DU CONCEPT EVOL_NOLI

      NUMCHA =  0
      CALL JEEXIN(CHARGE,IRET)
      IF ( IRET .NE. 0 ) THEN
        CALL JELIRA(CHARGE,'LONMAX',NCHAR,K8BID)
        CALL JEVEUO(CHARGE,'L',JCHAR)
        CALL JEVEUO(INFCHA,'L',JINF)
        NUMCHA = ZI(JINF+2*NCHAR+1)
      ENDIF
      IF ( NUMCHA .LE. 0 ) GOTO 9999

      NOM24 = ZK24(JCHAR+NUMCHA-1)(1:8)//'.CHME.TEMPE.TEMP'
      CALL JEVEUO(NOM24,'L',JTEMP)
      TEMPE = ZK8(JTEMP)
      CALL GETTCO(TEMPE,TYSD)
      IF (TYSD(1:9).NE.'EVOL_THER') GOTO 9999

      CALL DISMOI('F','NB_CHAMP_UTI',TEMPE,'RESULTAT',NBCHAM,
     &            K8BID,IRET)
      IF (NBCHAM.EQ.0) GOTO 9999


C    RECUPERATION DU CHAMP METALLURGIQUE DANS  EVOL_THER
      CALL RSINCH(TEMPE,'META_ELGA_TEMP','INST',INSTAN,PHASME,
     &            'CONSTANT','CONSTANT',0,'V',IRET)


 9999 CONTINUE
      CALL JEDEMA()
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/algorith/nmdeze.f <==
      SUBROUTINE NMDEZE (LISCHA,INSTAN,PHASME)

C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGORITH  DATE 04/04/2005   AUTEUR CIBHHPD L.SALMONA 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================

      IMPLICIT NONE
      CHARACTER*19   LISCHA, PHASME
      REAL*8         INSTAN
C ----------------------------------------------------------------------
C     EXTRACTION DU CHAMP DE CHANGEMENTS DE PHASES METALLURGIQUES
C
C IN        LISCHA  : SD L_CHARGES
C IN        INSTAN  : INSTANT DE L'EXTRACTION
C IN/JXOUT  PHASME  : CHAM_ELEM DE CHANGEMENTS DE PHASES METALLURGIQUES
C ----------------------------------------------------------------------

C --- DEBUT DECLARATIONS NORMALISEES JEVEUX ----------------------------
C
      CHARACTER*32       JEXNUM , JEXNOM , JEXR8 , JEXATR
      INTEGER            ZI
      COMMON  / IVARJE / ZI(1)
      REAL*8             ZR
      COMMON  / RVARJE / ZR(1)
      COMPLEX*16         ZC
      COMMON  / CVARJE / ZC(1)
      LOGICAL            ZL
      COMMON  / LVARJE / ZL(1)
      CHARACTER*8        ZK8
      CHARACTER*16                ZK16
      CHARACTER*24                          ZK24
      CHARACTER*32                                    ZK32
      CHARACTER*80                                              ZK80
      COMMON  / KVARJE / ZK8(1) , ZK16(1) , ZK24(1) , ZK32(1) , ZK80(1)
C
C --- FIN DECLARATIONS NORMALISEES JEVEUX ------------------------------
C
      INTEGER            NCHAR,IRET,NUMCHA,JCHAR,JINF, JTEMP, NBCHAM
      CHARACTER*8        TEMPE,K8BID
      CHARACTER*16       TYSD
      CHARACTER*24       CHARGE, INFCHA, NOM24, LIGRMO



      CALL JEMARQ()
      CALL DETRSD('CHAMP_GD',PHASME)

      CHARGE =  LISCHA // '.LCHA'
      INFCHA =  LISCHA // '.INFC'


C    EXTRACTION DU CONCEPT EVOL_NOLI

      NUMCHA =  0
      CALL JEEXIN(CHARGE,IRET)
      IF ( IRET .NE. 0 ) THEN
        CALL JELIRA(CHARGE,'LONMAX',NCHAR,K8BID)
        CALL JEVEUO(CHARGE,'L',JCHAR)
        CALL JEVEUO(INFCHA,'L',JINF)
        NUMCHA = ZI(JINF+2*NCHAR+1)
      ENDIF
      IF ( NUMCHA .LE. 0 ) GOTO 9999

      NOM24 = ZK24(JCHAR+NUMCHA-1)(1:8)//'.CHME.TEMPE.TEMP'
      CALL JEVEUO(NOM24,'L',JTEMP)
      TEMPE = ZK8(JTEMP)
      CALL GETTCO(TEMPE,TYSD)
      IF (TYSD(1:9).NE.'EVOL_THER') GOTO 9999

      CALL DISMOI('F','NB_CHAMP_UTI',TEMPE,'RESULTAT',NBCHAM,
     &            K8BID,IRET)
      IF (NBCHAM.EQ.0) GOTO 9999


C    RECUPERATION DU CHAMP METALLURGIQUE DANS  EVOL_THER
      CALL RSINCH(TEMPE,'META_ELNO_TEMP','INST',INSTAN,PHASME,
     &            'CONSTANT','CONSTANT',0,'V',IRET)


 9999 CONTINUE
      CALL JEDEMA()
      END
